@@ -7,6 +7,13 @@
 #' @param times A numeric vector storing the time points.
 #' @param series A numeric vector representing the values of the time series.
 #' @param series_esd A numeric vector representing the error standard deviations of the time series.
+#' @param times_phased A numeric vector of phased times.
+#' @param series_phased A numeric vector containing the time series values ordered by phase.
+#' @param series_esd_phased A numeric vector containing the error standard deviations of the time series ordered by phase. 
+#' @param fitted_values A numeric vector containing the fitted values from the harmonic model.
+#' @param residuals A numeric vector containing the residuals from the harmonic model.
+#' @param coef A numeric vector containing the estimated coefficients of the harmonic model.
+#' @param summary A summary object containing the harmonic model information.
 #' @param paired Data Frame with the paired datasets.
 #'
 #' @section Description:
@@ -31,6 +38,13 @@ utilities <- S7::new_class(
     times = S7::class_numeric,
     series = S7::class_numeric,
     series_esd = S7::class_numeric,
+    times_phased = S7::class_numeric,
+    series_phased = S7::class_numeric,
+    series_esd_phased = S7::class_numeric,
+    fitted_values = S7::class_numeric,
+    residuals = S7::class_numeric,
+    coef = S7::class_numeric,
+    summary = S7::class_list,
     paired = S7::class_numeric
   )
 )
